from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Int, String, File, Boolean

Run_Tipp_Py_V0_1_0 = CommandToolBuilder(tool="run_tipp.py", base_command=["run_tipp.py"], inputs=[ToolInput(tag="in_alignment_size", input_type=Int(optional=True), prefix="--alignmentSize", doc=InputDocumentation(doc="max alignment subset size of N [default: 10% of the\ntotal number of taxa or the placement subset size if\ngiven]")), ToolInput(tag="in_placement_size", input_type=Int(optional=True), prefix="--placementSize", doc=InputDocumentation(doc="max placement subset size of N [default: 10% of the\ntotal number of taxa or the alignment length\n(whichever bigger)]")), ToolInput(tag="in_fragment_chunksize", input_type=Int(optional=True), prefix="--fragmentChunkSize", doc=InputDocumentation(doc="maximum fragment chunk size of N. Helps controlling\nmemory. [default: 20000]")), ToolInput(tag="in_distance", input_type=Int(optional=True), prefix="--distance", doc=InputDocumentation(doc="minimum p-distance before stopping the\ndecomposition[default: 1]")), ToolInput(tag="in_diameter", input_type=String(optional=True), prefix="--diameter", doc=InputDocumentation(doc="maximum tree diameter before stopping the\ndecomposition[default: None]")), ToolInput(tag="in_decomp_strategy", input_type=Int(optional=True), prefix="--decomp_strategy", doc=InputDocumentation(doc="decomposition strategy [default: using tree branch\nlength]")), ToolInput(tag="in_tempdir", input_type=File(optional=True), prefix="--tempdir", doc=InputDocumentation(doc="Tempfile files will be written to DIR. Full-path\nrequired. [default: /tmp/sepp]")), ToolInput(tag="in_output", input_type=String(optional=True), prefix="--output", doc=InputDocumentation(doc="output files with prefix OUTPUT. [default: output]")), ToolInput(tag="in_outdir", input_type=File(optional=True), prefix="--outdir", doc=InputDocumentation(doc="output to OUTPUT_DIR directory. full-path required.\n[default: .]")), ToolInput(tag="in_config", input_type=File(optional=True), prefix="--config", doc=InputDocumentation(doc="A config file, including options used to run SEPP.\nOptions provided as command line arguments overwrite\nconfig file values for those options. [default: None]")), ToolInput(tag="in_tree", input_type=File(optional=True), prefix="--tree", doc=InputDocumentation(doc="Input tree file (newick format) [default: None]")), ToolInput(tag="in_ra_xml", input_type=File(optional=True), prefix="--raxml", doc=InputDocumentation(doc="RAxML_info file including model parameters, generated\nby RAxML.[default: None]")), ToolInput(tag="in_alignment", input_type=File(optional=True), prefix="--alignment", doc=InputDocumentation(doc="Aligned fasta file [default: None]")), ToolInput(tag="in_fragment", input_type=File(optional=True), prefix="--fragment", doc=InputDocumentation(doc="fragment file [default: None]")), ToolInput(tag="in_molecule", input_type=String(optional=True), prefix="--molecule", doc=InputDocumentation(doc="Molecule type of sequences. Can be amino, dna, or rna\n[default: dna]")), ToolInput(tag="in_cpu", input_type=Int(optional=True), prefix="--cpu", doc=InputDocumentation(doc="Use N cpus [default: number of cpus available on the\nmachine]")), ToolInput(tag="in_checkpoint", input_type=File(optional=True), prefix="--checkpoint", doc=InputDocumentation(doc="checkpoint file [default: no checkpointing]")), ToolInput(tag="in_interval", input_type=Int(optional=True), prefix="--interval", doc=InputDocumentation(doc="Interval (in seconds) between checkpoint writes. Has\neffect only with -cp provided. [default: 3600]")), ToolInput(tag="in_random_seed", input_type=Int(optional=True), prefix="--randomseed", doc=InputDocumentation(doc="random seed number. [default: 297834]")), ToolInput(tag="in_reference_pkg", input_type=String(optional=True), prefix="--reference_pkg", doc=InputDocumentation(doc="Use a pre-computed reference package [default: None]")), ToolInput(tag="in_alignment_threshold", input_type=Int(optional=True), prefix="--alignmentThreshold", doc=InputDocumentation(doc="Enough alignment subsets are selected to reach a\ncommulative probability of N. This should be a number\nbetween 0 and 1 [default: 0.95]")), ToolInput(tag="in_dist", input_type=Boolean(optional=True), prefix="--dist", doc=InputDocumentation(doc="Treat fragments as distribution")), ToolInput(tag="in_placement_threshold", input_type=Int(optional=True), prefix="--placementThreshold", doc=InputDocumentation(doc="Enough placements are selected to reach a commulative\nprobability of N. This should be a number between 0\nand 1 [default: 0.95]")), ToolInput(tag="in_push_down", input_type=String(optional=True), prefix="--push_down", doc=InputDocumentation(doc="Whether to classify based on children below or above\ninsertion point. [default: True]")), ToolInput(tag="in_taxonomy", input_type=File(optional=True), prefix="--taxonomy", doc=InputDocumentation(doc="A file describing the taxonomy. This is a comma-\nseparated text file that has the following fields:\ntaxon_id,parent_id,taxon_name,rank. If there are other\ncolumns, they are ignored. The first line is also\nignored.")), ToolInput(tag="in_taxonomy_name_mapping", input_type=File(optional=True), prefix="--taxonomyNameMapping", doc=InputDocumentation(doc="A comma-separated text file mapping alignment sequence\nnames to taxonomic ids. Formats (each line):\nsequence_name,taxon_id. If there are other columns,\nthey are ignored. The first line is also ignored.")), ToolInput(tag="in_alignment_decomposition_tree", input_type=File(optional=True), prefix="--alignmentDecompositionTree", doc=InputDocumentation(doc="A newick tree file used for decomposing taxa into\nalignment subsets. [default: the backbone tree]")), ToolInput(tag="in_cut_off", input_type=Int(optional=True), prefix="--cutoff", doc=InputDocumentation(doc="Placement probability requirement to count toward the\ndistribution. This should be a number between 0 and 1\n[default: 0.0]\n")), ToolInput(tag="in_v", input_type=Boolean(optional=True), prefix="-v", doc=InputDocumentation(doc=""))], outputs=[ToolOutput(tag="out_outdir", output_type=File(optional=True), selector=InputSelector(input_to_select="in_outdir", type_hint=File()), doc=OutputDocumentation(doc="output to OUTPUT_DIR directory. full-path required.\n[default: .]"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Run_Tipp_Py_V0_1_0().translate("wdl", allow_empty_container=True)

